@@ -4,8 +4,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     05/08/2003
-## RCS-ID:      $Id: wxGridTable.pm 2189 2007-08-21 18:15:31Z mbarbon $
-## Copyright:   (c) 2003, 2005, 2006 Mattia Barbon
+## RCS-ID:      $Id: wxGridTable.pm 3004 2011-02-13 13:09:03Z mbarbon $
+## Copyright:   (c) 2003, 2005, 2006, 2011 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -17,6 +17,22 @@ package Wx::DemoWindows::wxGridTable::Table;
 use strict;
 use base qw(Wx::PlGridTable);
 
+use Wx qw(wxRED wxGREEN);
+
+sub new {
+  my( $class ) = @_;
+  my $self = $class->SUPER::new;
+
+  $self->{default} = Wx::GridCellAttr->new;
+  $self->{red_bg} = Wx::GridCellAttr->new;
+  $self->{green_fg} = Wx::GridCellAttr->new;
+
+  $self->{red_bg}->SetBackgroundColour( wxRED );
+  $self->{green_fg}->SetTextColour( wxGREEN );
+
+  return $self;
+}
+
 sub GetNumberRows { 100000 }
 sub GetNumberCols { 100000 }
 sub IsEmptyCell { 0 }
@@ -61,6 +77,15 @@ sub GetValueAsDouble {
   return $r + $c / 1000;
 }
 
+sub GetAttr {
+  my( $self, $row, $col, $kind ) = @_;
+
+  return $self->{default} if $row % 2 && $col % 2;
+  return $self->{red_bg} if $row % 2;
+  return $self->{green_fg} if $col % 2;
+  return Wx::GridCellAttr->new;
+}
+
 package Wx::DemoModules::wxGridTable;
 
 use strict;
