@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     26/08/2007
-## RCS-ID:      $Id: wxPasswordEntryDialog.pm 2212 2007-08-25 23:13:10Z mbarbon $
+## RCS-ID:      $Id: wxPasswordEntryDialog.pm 2812 2010-02-20 10:53:40Z mbarbon $
 ## Copyright:   (c) 2007 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -41,7 +41,7 @@ sub text_entry_dialog {
   $dialog->Destroy;
 }
 
-sub add_to_tags { qw(dialogs new) }
+sub add_to_tags { qw(dialogs) }
 sub title { 'wxPasswordEntryDialog' }
 
 defined &Wx::PasswordEntryDialog::new;
